summaryrefslogtreecommitdiffstats
path: root/tests/functional/snapshot/test_validate_snapshot_rebalance.py
diff options
context:
space:
mode:
Diffstat (limited to 'tests/functional/snapshot/test_validate_snapshot_rebalance.py')
-rw-r--r--tests/functional/snapshot/test_validate_snapshot_rebalance.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/functional/snapshot/test_validate_snapshot_rebalance.py b/tests/functional/snapshot/test_validate_snapshot_rebalance.py
index 7eb674475..f9e018d64 100644
--- a/tests/functional/snapshot/test_validate_snapshot_rebalance.py
+++ b/tests/functional/snapshot/test_validate_snapshot_rebalance.py
@@ -55,7 +55,7 @@ class SnapCreateRebal(GlusterBaseClass):
during rebalance
9. After rebalance is completed, create snapshots with the same name as
in Step 7
- -- this operation should be sucessfull
+ -- this operation should be successful
10. Cleanup
"""
@@ -103,7 +103,7 @@ class SnapCreateRebal(GlusterBaseClass):
ret = self.unmount_volume_and_cleanup_volume(self.mounts)
if not ret:
raise ExecutionError("Failed to cleanup volume and mount")
- g.log.info("Cleanup successfull for the volume and mount")
+ g.log.info("Cleanup successful for the volume and mount")
def test_snapshot_while_rebalance(self):
# pylint: disable=too-many-statements, missing-docstring